==> core-2.0.1.1-sources.jar: io/adbrix/sdk/data/ConfigConstants.java <==
package io.adbrix.sdk.data;

import org.json.JSONArray;

import java.util.HashMap;
import java.util.Map;

public class ConfigConstants {

    private ConfigConstants(){}

    public static final boolean CONFIG_DEFAULT_ADBRIX_PAUSE = false;
    public static final JSONArray CONFIG_DEFAULT_BLOCKED_EVENT_LIST = null;
    public static final boolean CONFIG_DEFAULT_APP_SCAN_ON_OFF = true;
    public static final int CONFIG_DEFAULT_APP_SCAN_PERIOD = 100;
    public static final int CONFIG_DEFAULT_PROPERTY_MAX_SIZE = 100;
    public static final boolean CONFIG_DEFAULT_ADBRIX_ALL_STOP = false;
    public static final String CONFIG_DEFAULT_SK_IP_PORT = "12700000000104200";
    public static final int CONFIG_DEFAULT_SK_PING_VERSION = 1;
    public static final int CONFIG_DEFAULT_SK_PING_PERIOD_SECOND = 300;

    public static final String S3_CONFIG_ADBRIX_PAUSE = "red";
    public static final String S3_CONFIG_BLOCKED_EVTLIST = "white";
    public static final String S3_CONFIG_PROPERTY_KEY_MAX = "green";
    public static final String S3_CONFIG_APP_SCAN_PERIOD = "pink";
    public static final String S3_CONFIG_APP_SCAN_STOP = "yellow";
    public static final String S3_CONFIG_ADBRIX_ALL_STOP= "blue";
    public static final String S3_CONFIG_SK_IP_PORT = "beige";
    public static final String S3_CONFIG_SK_PING_VERSION = "brown";
    public static final String S3_CONFIG_SK_PING_PERIOD_SECOND = "ivory";

    public static final Map<String, Integer> S3Key = createSetS3();
    private static Map<String, Integer> createSetS3()
    {
        Map<String,Integer> S3Key = new HashMap<>();
        S3Key.put("3a2cf27458c9aa3e358f8fc0f002bff6", 0); //melon
        S3Key.put("8893dc16b1b2534bab7b03727145a2bb", 1); //pear
        S3Key.put("b781cbb29054db12f88f08c6e161c199", 2); //grape
        S3Key.put("fe01d67a002dfa0f3ac084298142eccd", 3); //orange
        S3Key.put("3f24e567591e9cbab2a7d2f1f748a1d4", 4); //lemon
        S3Key.put("c7a4476fc64b75ead800da9ea2b7d072", 5); //cherry
        S3Key.put("495bf9840649ee1ec953d99f8e769889", 6); //strawberry
        S3Key.put("de5949721e6352f01dfef317c3e898a8", 7); //kiwi
        S3Key.put("889560d93572d538078ce1578567b91a", 8); //peach
        S3Key.put("2d6128bc89c98dc7a4462e8b310997a4", 9); //papaya
        S3Key.put("72b302bf297a228a75730123efef7c41", 10); //banana

        S3Key.put("a9a58fdf2d0f37bad48f6894f08c0dbf", 20); //eshallot
        S3Key.put("792aa0c6be3e339be78732f13b430afd", 30); //daikon
        S3Key.put("4ff258784836201af40c76e8eab23a99", 40); //zucchini
        S3Key.put("ccf6184efe5e38da61ef2e9a30d1c1ea", 50); //garlic
        S3Key.put("a784e16cad62de5c22b5eb96428fe683", 60); //soybean
        S3Key.put("006f87892f47ef9aa60fa5ed01a440fb", 70); //tomato
        S3Key.put("4e026537a7d32360c5a22b7cb2e7f61a", 80); //mushroom
        S3Key.put("b3f952d5d9adea6f63bee9d4c6fceeaa", 90); //pepper
        S3Key.put("df5d07e9c21209fb3b498f4ddee0f04e", 100); //okra

        S3Key.put("79a7b1f0b4044985f75e8a83533608f2", 200); //gum
        S3Key.put("c48ba993d35c3abe0380f91738fe2a34", 300); //candy
        S3Key.put("9944fe83a25e72559c62d612485de579", 400); //muffin
        S3Key.put("c378985d629e99a4e86213db0cd5e70d", 500); //chocolate
        S3Key.put("328356824c8487cf314aa350d11ae145", 600); //jelly
        S3Key.put("287c683aedfe88bbfb62cea45b29bd08", 700); //snack
        S3Key.put("ecbdb882ae865a07d87611437fda0772", 800); //milk
        S3Key.put("57f7e96f370e04546066ee921424c760", 900); //juice
        S3Key.put("cb2a6b634f36e7f2f79d58956819a2d8", 1000); //coke

        return S3Key;
    }
}

==> core-2.1.0.0-sources.jar: io/adbrix/sdk/data/ConfigConstants.java <==
package io.adbrix.sdk.data;

import org.json.JSONArray;

import java.util.HashMap;
import java.util.Map;

public class ConfigConstants {

    private ConfigConstants(){}

    public static final boolean CONFIG_DEFAULT_ADBRIX_PAUSE = false;
    public static final JSONArray CONFIG_DEFAULT_BLOCKED_EVENT_LIST = null;
    public static final boolean CONFIG_DEFAULT_APP_SCAN_ON_OFF = true;
    public static final int CONFIG_DEFAULT_APP_SCAN_PERIOD = 100;
    public static final int CONFIG_DEFAULT_PROPERTY_MAX_SIZE = 100;
    public static final boolean CONFIG_DEFAULT_ADBRIX_ALL_STOP = false;
    public static final String CONFIG_DEFAULT_SK_IP_PORT = "12700000000104200";
    public static final int CONFIG_DEFAULT_SK_PING_VERSION = 1;
    public static final int CONFIG_DEFAULT_SK_PING_PERIOD_SECOND = 300;
    public static final boolean CONFIG_DEFAULT_IN_APP_MESSAGE_ACTIVE = false;

    public static final String S3_CONFIG_ADBRIX_PAUSE = "red";
    public static final String S3_CONFIG_BLOCKED_EVTLIST = "white";
    public static final String S3_CONFIG_PROPERTY_KEY_MAX = "green";
    public static final String S3_CONFIG_APP_SCAN_PERIOD = "pink";
    public static final String S3_CONFIG_APP_SCAN_STOP = "yellow";
    public static final String S3_CONFIG_ADBRIX_ALL_STOP= "blue";
    public static final String S3_CONFIG_SK_IP_PORT = "beige";
    public static final String S3_CONFIG_SK_PING_VERSION = "brown";
    public static final String S3_CONFIG_SK_PING_PERIOD_SECOND = "ivory";
    public static final String S3_CONFIG_IN_APP_MESSAGE_ACTIVE = "purple";

    public static final Map<String, Integer> S3Key = createSetS3();
    private static Map<String, Integer> createSetS3()
    {
        Map<String,Integer> S3Key = new HashMap<>();
        S3Key.put("3a2cf27458c9aa3e358f8fc0f002bff6", 0); //melon
        S3Key.put("8893dc16b1b2534bab7b03727145a2bb", 1); //pear
        S3Key.put("b781cbb29054db12f88f08c6e161c199", 2); //grape
        S3Key.put("fe01d67a002dfa0f3ac084298142eccd", 3); //orange
        S3Key.put("3f24e567591e9cbab2a7d2f1f748a1d4", 4); //lemon
        S3Key.put("c7a4476fc64b75ead800da9ea2b7d072", 5); //cherry
        S3Key.put("495bf9840649ee1ec953d99f8e769889", 6); //strawberry
        S3Key.put("de5949721e6352f01dfef317c3e898a8", 7); //kiwi
        S3Key.put("889560d93572d538078ce1578567b91a", 8); //peach
        S3Key.put("2d6128bc89c98dc7a4462e8b310997a4", 9); //papaya
        S3Key.put("72b302bf297a228a75730123efef7c41", 10); //banana

        S3Key.put("a9a58fdf2d0f37bad48f6894f08c0dbf", 20); //eshallot
        S3Key.put("792aa0c6be3e339be78732f13b430afd", 30); //daikon
        S3Key.put("4ff258784836201af40c76e8eab23a99", 40); //zucchini
        S3Key.put("ccf6184efe5e38da61ef2e9a30d1c1ea", 50); //garlic
        S3Key.put("a784e16cad62de5c22b5eb96428fe683", 60); //soybean
        S3Key.put("006f87892f47ef9aa60fa5ed01a440fb", 70); //tomato
        S3Key.put("4e026537a7d32360c5a22b7cb2e7f61a", 80); //mushroom
        S3Key.put("b3f952d5d9adea6f63bee9d4c6fceeaa", 90); //pepper
        S3Key.put("df5d07e9c21209fb3b498f4ddee0f04e", 100); //okra

        S3Key.put("79a7b1f0b4044985f75e8a83533608f2", 200); //gum
        S3Key.put("c48ba993d35c3abe0380f91738fe2a34", 300); //candy
        S3Key.put("9944fe83a25e72559c62d612485de579", 400); //muffin
        S3Key.put("c378985d629e99a4e86213db0cd5e70d", 500); //chocolate
        S3Key.put("328356824c8487cf314aa350d11ae145", 600); //jelly
        S3Key.put("287c683aedfe88bbfb62cea45b29bd08", 700); //snack
        S3Key.put("ecbdb882ae865a07d87611437fda0772", 800); //milk
        S3Key.put("57f7e96f370e04546066ee921424c760", 900); //juice
        S3Key.put("cb2a6b634f36e7f2f79d58956819a2d8", 1000); //coke

        return S3Key;
    }
}
